#
# spec file for package perl-HTTP-DAV
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTTP-DAV
Name:           perl-HTTP-DAV
Version:        0.500.0
Release:        1.1
# 0.50 -> normalize -> 0.500.0
%define cpan_version 0.50
#Upstream:  Patrick Collins G03 Gloucester Place, Kensington Sydney, Australia Email: pcollins@cpan.org Phone: +61 2 9663 4916 All rights reserved. Current co-maintainer of the module is Cosimo Streppone for Opera Software ASA, the opera@cpan.org manpage. You may distribute this module under the terms of either the GNU General Public License or the Artistic License, as specified in the Perl README file.
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        WebDAV client library for Perl5
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/C/CO/COSIMO/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(LWP) >= 5.48
BuildRequires:  perl(URI)
BuildRequires:  perl(URI::Escape)
BuildRequires:  perl(XML::DOM)
Requires:       perl(LWP) >= 5.48
Requires:       perl(URI)
Requires:       perl(URI::Escape)
Requires:       perl(XML::DOM)
Provides:       perl(HTTP::DAV) = %{version}
Provides:       perl(HTTP::DAV::Comms)
Provides:       perl(HTTP::DAV::Headers)
Provides:       perl(HTTP::DAV::Lock) = 0.09
Provides:       perl(HTTP::DAV::Resource) = %{version}
Provides:       perl(HTTP::DAV::ResourceList) = 0.11
Provides:       perl(HTTP::DAV::Response) = 0.14
Provides:       perl(HTTP::DAV::UserAgent)
Provides:       perl(HTTP::DAV::Utils) = 0.11
%undefine       __perllib_provides
%{perl_requires}

%description
HTTP::DAV is a Perl API for interacting with and modifying content on
webservers using the WebDAV protocol. Now you can LOCK, DELETE and PUT
files and much more on a DAV-enabled webserver.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes doc README TODO

%changelog
* Thu Oct 17 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.500.0 (0.50)
  see /usr/share/doc/packages/perl-HTTP-DAV/Changes
    v0.50 (released 2024/10/16):
  * bug fixes
    Fixed missing custom headers when calling PUT methods. Closes
    "RT#100756". Thanks Georg Acher for the patch and for patiently
    waiting a decade (!) for a fix.
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.49
  see /usr/share/doc/packages/perl-HTTP-DAV/Changes
    v0.49 (released 2018/11/28):
  * bug fixes
    Fixed perl shebang line in "dave" script, for ExtUtils::MakeMaker to
    correctly replace it. Closes "RT#127819".
    Fixed "propfind" response handling to also consider successful an
    HTTP 207 status code. Closes "RT#127591".
    Fixed "clone()" method to properly respect the class name. Closes
    "RT#123528". Thanks to Ricardo Signes for the patch.
  * documentation fixes
    Fixed various pod issues raised by Debian contributor
    "fsfs@debian.org". Closes "RT#119878".
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.48
  see /usr/share/doc/packages/perl-HTTP-DAV/Changes
    v0.48 (released 2015/03/26):
  * bug fixes
    "RT#103126", fixed faulty code to add trailing slash to URLs.
    v0.47 (released 2012/03/24):
  * bug fixes
    Improve "propfind()" resilience when server response contains
    broken, truncated or no XML at all. RT#75011.
* Wed Jun  5 2013 coolo@suse.com
- updated to 0.47
  Improve C<propfind()> resilience when server response contains
  broken, truncated or no XML at all. RT#75011.
* Fri Jan 13 2012 vcizek@suse.com
- update to 0.46
  * improvements
    HTTP::DAV should now be working with more WebDAV servers.
    We are more flexible in what content types we consider to be XML.
    Thanks Ron1 and Adam for the feedback and patches.
* Mon Sep 19 2011 vcizek@suse.com
- update to 0.45
  - Mostly cosmetic changes (no changelog from the upstream)
* Wed Jun 22 2011 vcizek@novell.com
- update to 0.44
  * bug fixes
  - Fixed RT #68936 (http://rt.cpan.org/Public/Bug/Display.html?id=68936),
    Fixed errors() method that would bomb out when the "_errors" attribute
    wasn't initialized. Thanks to Michael Lackoff for reporting.
* Fri Apr 15 2011 vcizek@novell.com
- update to 0.43
  - Fixed RT #38677 (http://rt.cpan.org/Public/Bug/Display.html?id=38677),
    Intercept correctly 405 (Method now allowed) errors and report them
    to the clients.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 22 2010 anicka@suse.cz
- update to 0.42
  * Fixed RT #60457 (http://rt.cpan.org/Public/Bug/Display.html?id=60457),
  Added and documented possibility to pass your own custom HTTP headers.
  * Fixed errors in the code examples in the synopsis.
* Tue Jul 27 2010 chris@computersalat.de
- update to 0.41
- Fixed RT #59674 (http://rt.cpan.org/Public/Bug/Display.html?id=59674),
  When SSL support is needed but not installed, a more specific
  error messages is now displayed, instead of "not DAV enabled
  or not accessible".
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Tue Feb 23 2010 anicka@suse.cz
- update to 0.40
  * HTTP::DAV::Comms->credentials() method erroneously autovivified
  basic authentication internal values, causing wrong or undefined
  credentials to be sent out, or credentials to be "forgot" by HTTP::DAV.
* Wed Jan 13 2010 anicka@suse.cz
- update to 0.39
  * Fixed RT #52665 (http://rt.cpan.org/Public/Bug/Display.html?id=52665),
  Using dave or propfind() on URLs containing escaped chars (%%xx) could fail,
    due to upper/lower case differences. Thanks to cebjyre for the patch
    and the test case.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 0.38
  * Fixed RT #14506 (http://rt.cpan.org/Public/Bug/Display.html?id=14506),
  about the missing get_lastresponse() method. It was a documentation bug.
  * Fixed RT #29788 (http://rt.cpan.org/Public/Bug/Display.html?id=29788),
  avoid file corruptions on Win32 when calling HTTP::DAV::get() method.
  * Fixed RT #31014 (http://rt.cpan.org/Public/Bug/Display.html?id=31014),
  probably already in v0.34, since it seems related to propfind() "depth" bug.
* Tue Mar 24 2009 anicka@suse.cz
- update to 0.37
  * Fixed RT #44409 Small bug in HTTP::DAV::put(). Passing a reference
  as local content resulted in the "SCALAR(0x12345678)" being logged
  instead of the real scalar.
* Fri Feb 27 2009 anicka@suse.cz
- update to 0.36
  * Fixed RT #19616 (http://rt.cpan.org/Public/Bug/Display.html?id=19616),
  LWP::UserAgent::redirect_ok() is not changed anymore. We're subclassing
  it from HTTP::DAV::UserAgent and overriding redirect_ok() there.
  * Fixed RT #42877 (http://rt.cpan.org/Public/Bug/Display.html?id=42877),
  HTTP::DAV::UserAgent::credentials() has been modified to behave like
  LWP::UserAgent::credentials(), otherwise basic authentication breakages
  can occur.
  * Fixed a problem with C<-depth> argument to C<HTTP::DAV::propfind()> that
  could lead to massive performance degradation, especially when running
  C<propfind()> against large folders.
  C<-depth> was set to 1 even when passed as zero.
- fix permissions, ends of lines and perl dependency
* Tue Jan 20 2009 anicka@suse.cz
- update to 0.35
  * Fixed getting single or multiple files directly to \*STDOUT.
* Thu Sep 11 2008 anicka@suse.cz
- update to 0.34
  * fixed downloading multiple files in the same directory.
* Wed Sep 10 2008 anicka@suse.cz
- update to 0.33
  * Clearly state that Opera Software ASA is now co-maintainer of
    HTTP::DAV
  * Fixed various inconsistencies in the v0.32 documentation
  * Now HTTP::DAV requires Perl 5.6.0+ and Scalar::Util
  (core in 5.8.x).
  * Now HTTP::DAV objects are correctly released from memory when
  they go out of scope. Now it should be possible to use multiple
  instances of HTTP::DAV even in long-running processes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Wed Jan 28 2004 ro@suse.de
- created package (version 0.31)
